/* This file is part of Ebola: El octavo pasajero. */

/*     Ebola: El octavo pasajero is free software: you can redistribute it and/or modify */
/*     it under the terms of the GNU General Public License as published by */
/*     the Free Software Foundation, either version 3 of the License, or */
/*     (at your option) any later version. */

/*     Ebola: El octavo pasajero is distributed in the hope that it will be useful, */
/*     but WITHOUT ANY WARRANTY; without even the implied warranty of */
/*     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the */
/*     GNU General Public License for more details. */

/*     You should have received a copy of the GNU General Public License */
/*     along with Ebola: El octavo pasajero.  If not, see <http://www.gnu.org/licenses/>. */

/*
  @file controller.h
  @brief The controller file, control the keys pressed and the sounds.
  @author Jesus Manresa Parres
  @version 1
*/

#ifndef __CONTROLLER_H__
#define __CONTROLLER_H__

#include <keyboard.h>

/**
	@brief Scan the keyboard and return a array with the pressed keys.
	
	@return const int*  The array of keys ( right, left, up, down, space)
*/
unsigned char controllerScanKeys()
{
	unsigned char keys= 0x00;
	cpct_scanKeyboardFast();

	if(cpct_isKeyPressed(Key_CursorRight) & 0x01)
		keys^=0x80;
	else if(cpct_isKeyPressed(Key_CursorLeft) & 0x01)
		keys^=0x40;
	
	if(cpct_isKeyPressed(Key_CursorUp) & 0x01)
		keys^=0x20;
	else if(cpct_isKeyPressed(Key_CursorDown) & 0x01)
		keys^=0x10;
	
	if(cpct_isKeyPressed(Key_A) & 0x01)
		keys^=0x08;
	else if(cpct_isKeyPressed(Key_D) & 0x01)
		keys^=0x04;

	if(cpct_isKeyPressed(Key_W) & 0x01)
		keys^=0x02;
	else if(cpct_isKeyPressed(Key_S) & 0x01)
		keys^=0x01;
	
	return keys;
}


/**	
	@brief Touch a key for exit.
*/
void exit()
{
  __asm
    call #0xBB06
  __endasm;  

}

#endif
