/* This file is part of Ebola: El octavo pasajero. */

/*     Ebola: El octavo pasajero is free software: you can redistribute it and/or modify */
/*     it under the terms of the GNU General Public License as published by */
/*     the Free Software Foundation, either version 3 of the License, or */
/*     (at your option) any later version. */

/*     Ebola: El octavo pasajero is distributed in the hope that it will be useful, */
/*     but WITHOUT ANY WARRANTY; without even the implied warranty of */
/*     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the */
/*     GNU General Public License for more details. */

/*     You should have received a copy of the GNU General Public License */
/*     along with Ebola: El octavo pasajero.  If not, see <http://www.gnu.org/licenses/>. */

/*
  @file my_models.h
  @brief The models file.
  @author Jesus Manresa Parres, Francisco Manuel Garcia Botella, Primo Escandell Luis, Almira Molla Alejandro
  @version 1
*/
#ifndef __MY_MODELS_H__
#define __MY_MODELS_H__
/** 
  @short The height of a tile.
*/
#define TILE_HEIGHT 8

/**
  @short The width of a tile.
*/
#define TILE_WIDTH 8

/**
  @short The height of the screen in mode 0.
*/
#define SCREEN_HEIGHT 176 //[200] 24 -> For info tile, life and score.

/**
  @short The width of the screen in mode 0.
*/
#define SCREEN_WIDTH 160

/**
  @short The number of tiles of height.
*/
#define NUM_TILES_HEIGHT SCREEN_HEIGHT/TILE_HEIGHT

/** 
  @short The number of tiles of width.
*/
#define NUM_TILES_WIDTH SCREEN_WIDTH/TILE_WIDTH

/**
    @brief The width of the arcademap.
*/
#define ARCADEMAP_WIDTH 32

/**
    @brief The height of the arcademap. 
*/
#define ARCADEMAP_HEIGHT 32

/**
  @brief The number of max shoots.
*/
#define MAX_SHOOTS 6

/**
   @brief Number of enemies.
*/
#define ENEMIES 8

/**
    @brief Number of footprints.
*/
#define MAX_FOOTPRINTS 10

/**
    @brief Number of waypoints.
*/
#define MAX_WAYPOINTS 10


/**
    @short The enum of map.
*/
enum BackgroundMapType
{
  MAP_NONE,
  MAP_BORDER,
  MAP_CHARACTER,
  MAP_SHOOT,
  MAP_ENEMY,
  MAP_ILLENEMY,
  MAP_EXPLOSION,
  MAP_FOOTPRINT,
  MAP_SHOOTH2,
  MAP_SHOOTV1,
  MAP_SHOOTV2,
  MAP_HEART_FULL,
  MAP_HEART_EMPTY,
  MAP_CAMILLA,

};

/**
  @short The enum of character.
*/
enum CharacterType
{
    CHARACTER_RIGHT,
    CHARACTER_LEFT,
    CHARACTER_UP,
    CHARACTER_DOWN
};

/**
  @short The enum of enemy.
*/
enum EnemyType
{
    ENEMY_RIGHT,
    ENEMY_LEFT,
    ENEMY_UP,
    ENEMY_DOWN
};



/**
  @short The struct of position.
*/
struct TPosition
{
  unsigned char ox;
  unsigned char oy;
  unsigned char x;
  unsigned char y;
};

/**
  @short The struct of simple position.
*/
struct TSimplePosition
{
  unsigned short x;
  unsigned short y;
};

/**
  @short The states of the enemy
*/
enum EnemyState
{
  QUIET,
  ALERT,
  QUIT_ALERT,
  AWARE
};

/**
  @short The struct of an enemy
*/
struct TEnemy
{
  struct TPosition position;
  enum EnemyState state;
  enum EnemyType direction;
	unsigned char life;
};

///**
// @short The struct of shots.
//*/

struct TShot
{
  struct TPosition position;
  unsigned char dir;
};

/**
 @brief Aleatorie
**/
unsigned char const Aleatorie[]=
{
  1,0,1,0,1,0,1,0,1,0
};

/**
  @brief The arcade map.
*/
const unsigned char ArcadeMap[]=
{
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1,
    1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1,
    1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1,
    1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1,
    1, 0, 0, 0, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 0, 0, 0, 1,
    1, 0, 0, 0, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 0, 0, 0, 1,
    1, 0, 0, 0, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 0, 0, 0, 1,
    1, 0, 0, 0, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 0, 0, 0, 1,
    1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1,
    1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1,
    1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1,
    1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1,
    1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1,
    1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1,
    1, 0, 0, 0, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 0, 0, 0, 1,
    1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1,
    1, 0, 0, 0, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 0, 0, 0, 1,
    1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1,
    1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1,
    1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1,
    1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1,
    1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1,
    1, 0, 0, 0, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 0, 0, 0, 1,
    1, 0, 0, 0, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 0, 0, 0, 1,
    1, 0, 0, 0, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 0, 0, 0, 1,
    1, 0, 0, 0, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 0, 0, 0, 1,
    1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1,
    1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1,
    1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1,
    1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 
};

#endif
