/* This file is part of Ebola: El octavo pasajero. */

/*     Ebola: El octavo pasajero is free software: you can redistribute it and/or modify */
/*     it under the terms of the GNU General Public License as published by */
/*     the Free Software Foundation, either version 3 of the License, or */
/*     (at your option) any later version. */

/*     Ebola: El octavo pasajero is distributed in the hope that it will be useful, */
/*     but WITHOUT ANY WARRANTY; without even the implied warranty of */
/*     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the */
/*     GNU General Public License for more details. */

/*     You should have received a copy of the GNU General Public License */
/*     along with Ebola: El octavo pasajero.  If not, see <http://www.gnu.org/licenses/>. */

/*
  @file view.h
  @brief The view file,draw the sprites.
  @author Jesus Manresa Parres, Francisco Manuel Garcia Botella
  @version 1
*/

#ifndef __VIEW_H__
#define __VIEW_H__

#include <sprites.h>
#include <firmware_ed.h>
#include "model.h"
#include "my_sprites.h"

unsigned char contador = 0;
/**
	@brief Set the color.

	@param[in] colorIndex the number to assign.
	@param[in] paletteIndex the color of palette.
*/
void setColor(unsigned char colorIndex, unsigned char paletteIndex)
{
  colorIndex; paletteIndex;
  
  __asm
    push ix
    ld ix, #0
    add ix, sp
    ld a, 2 (ix)
    ld b, 3 (ix)
    ld c, b
    call #0xBC32 ;SCR SET INK
    pop ix
  __endasm;
}

/**
	@brief Initialize the palette.
*/
void initPalette()
{
  unsigned char nColor= 0;
  for(nColor=0; nColor < NUM_COLORS; nColor++)
    setColor(nColor, palette_[nColor]);
  
}

void initMode0AndBlackBorder()
{
    __asm
    ld a, #0
    call #0xBC0E
    //SCR SET BORDER 0
    ld b, #0 ;black
    ld c, b
    call #0xBC38
    ld b, #4
  wait:
    halt
    djnz wait
  __endasm;
}


void initMode0()
{
  initMode0AndBlackBorder();
  initPalette();
  cpct_disableFirmware();
}


/**
  @brief Get the address.

  @param[in] coord x.
  @param[in] coord y.
*/  
unsigned char *getLineAdress(unsigned int x, unsigned int y) 
{
  return (((unsigned char*)0XC000 + ((y/8)*80) + ((y%8)*2048)) + x/2);
}

/**	
	@brief Paint a tile.

	@param[x] the coord x.
	@param[y] the coord y.
*/

void drawTile(unsigned char x, unsigned char y)
{
  unsigned int nY= y * TILE_HEIGHT;
  unsigned int nX= x * TILE_WIDTH;
  unsigned char* pSprite= (unsigned char*)SpriteGrass;

  switch(backgroundTiles_[positionOnMap.x + x][positionOnMap.y + y])
  {
  case MAP_NONE: pSprite= (unsigned char*) SpriteGrass; break;
  case MAP_BORDER: pSprite= (unsigned char*) SpriteBorder; break;
  case MAP_CHARACTER: pSprite= (unsigned char*) SpriteCharacter; break;
  case MAP_SHOOT: pSprite= (unsigned char*) SpriteShootH1; break;
  case MAP_SHOOTH2: pSprite = (unsigned char*) SpriteShootH2;break;
  case MAP_SHOOTV1: pSprite = (unsigned char*) SpriteShootV1;break;
  case MAP_SHOOTV2: pSprite = (unsigned char*) SpriteShootV2;break;
  case MAP_ENEMY: pSprite= (unsigned char*) SpriteEnemy; break;
  case MAP_ILLENEMY: pSprite=(unsigned char*) SpriteIllEnemy;break;
  case MAP_EXPLOSION: pSprite=(unsigned char*)SpriteExplosion; break;
  case MAP_HEART_FULL: pSprite=(unsigned char*) SpriteHeartFull;break;
  case MAP_HEART_EMPTY: pSprite=(unsigned char*)SpriteHeartEmpty;break;
  case MAP_CAMILLA: pSprite=(unsigned char*)SpriteCamilla;break;
  }
  
  cpct_drawSprite4x8_aligned(pSprite, getLineAdress(nX, nY));
}

/**
  @brief Show the tile map. ONLY USE ONE TIME, AFTER RENDERING BUCLE.
*/
void showTileMap()
{
  unsigned char x,y;

  for(x= 0; x<NUM_TILES_WIDTH; ++x)
    for(y= 0; y<NUM_TILES_HEIGHT; ++y)
        drawTile(x,y);

}

/**
	@brief Draw the tile map
*/
void drawTileMap()
{
  unsigned char x,y;
  ++contador;
  for(x= 0; x<NUM_TILES_WIDTH; ++x)
	  for(y= 0; y<NUM_TILES_HEIGHT; ++y)
		  if(backgroundTiles_[positionOnMap.x+x][positionOnMap.y+y]!=backgroundTilesSecondary_[positionOnMap.ox+x][positionOnMap.oy+y])
			  drawTile(x,y);
  if(contador > 10)
	  contador = 0;
}

#endif
